<?php

/**
 * Plugin Name: WP Site Links.
 * Plugin URI: 
 * Description: Allows you to easily access links to your other posts and pages through a widget.
 * Version: 0.1.1
 * Author: Mark Skilbeck
 * Author URI: http://mahcuz.com
 */

class WP_Site_Links
{
	/**
	 * Pseudo-Constants
	 * PLUGIN_DIR path to plugin dir.
	 * PLUGIN_URL url to plugin dir.
	 * - same for content (but to content dir)
	 * APP_VER current app version.
	 */
	private $PLUGIN_DIR;
	private $PLUGIN_URL;
	private $CONTENT_URL;
	private $CONTENT_DIR;
	private $APP_VER = "0.1";

	/**
	 * Class properties.
	 * db_model - our reference to $wpdb
	 */
	private $db_model;

	/**
	 * Constructor.
	 * Sets the hooks, variables, etc.
	 */
	public function WP_Site_Links ()
	{
		global $wpdb;
		$this->db_model = $wpdb;
		// Set hooks.
		add_action( 'init', array ( $this, 'SetVariables' ), 1001 );
		add_action( 'wp_head', array ( $this, 'AddStyles' ), 1001 );
		add_action( 'admin_head', array ( $this, 'AddStyles' ), 1001 );
		add_action( 'admin_menu', array ( $this, 'AddMetaBox' ));
		add_action( 'admin_footer', array ( $this, 'EnqueueScripts' ), 1001 );

		// Adds filters.
		add_action( 'init', array($this, 'AddFilters'), 1001 );
	}

	public function SetVariables ( )
	{
		// Pseudo-Constants.
		$this->CONTENT_URL = get_option( 'siteurl' ) . '/wp-content' ;
		$this->CONTENT_DIR = ABSPATH . 'wp-content' ;
		$this->PLUGIN_URL  = $this->CONTENT_URL . '/plugins' ;
		$this->PLUGIN_DIR  = $this->CONTENT_DIR . '/plugins' ;
	}
	
	public function EnqueueScripts ( )
	{
		// Get the contents of file.
		$js = file_get_contents( $this->PLUGIN_DIR . '/WP Site Links/js/wp-site-links.js' );
		echo "<script type='text/javascript'>{$js}</script>";
	}

	public function AddStyles ( )
	{
		echo "<link href='{$this->PLUGIN_URL}/WP Site Links/style.css' type='text/css' rel='stylesheet' />";
	}

	public function AddFilters ( )
	{
		// Add the media button, to insert headings, etc.
		add_filter( 'media_buttons', array($this, 'SetMediaButton') , 1001);
	}

	public function AddMetaBox ( )
	{
		// Adds a box to the post page.
		add_meta_box( 
				'wp_links_metabox', 			// The boxes ID
				'WP Site Links', 				// The title to show on the box.
				array( $this, 'MetaBoxData' ),  // The function for the output.
				'post', 						// Context: page or post.
				'side',							// Page placement: normal, advanced, side.
				'low'							// Priority: high or low (where the box will show).
				);
		// And the same for le 'page' page. heh.
		add_meta_box(
				'wp_links_metabox',
				'WP Site Links',
				array( $this, 'MetaBoxData' ),
				'page',
				'side',
				'low'
				);
	}

	public function MetaBoxData ()
	{
		// Grab post links
		$sql = "
			SELECT 
				`post_title`, `guid`
			FROM
				`{$this->db_model->posts}`
			WHERE
				`post_status` = 'publish'
			ORDER BY `ID` DESC";
		$page_links = $this->db_model->get_results( $sql );

		echo "<ul class='wp_links_ul'>";

		foreach( $page_links as $link )
		{
			$this->truncate( $link->post_title );
			echo "
			<li>
				<a
					title='". htmlentities($link->post_title, ENT_QUOTES)."' 
					onmouseup='return false;'
					href='javascript:;'
					class='{$link->guid}'>
						". $this->truncate( $link->post_title ) ."</a>
			</li>";
		}

		echo "</ul>";
	}

	public function truncate ( $str )
	{
		if ( strlen( $str ) > 30 ) 
		{
			$str = substr($str, 0, 30);
			$temp = strrpos($str, ' ');
			$str = substr($str, 0, $temp) . ' ...';
			return $str;
		} 
		else 
		{
			return $str;
		}
	}

	public function SetMediaButton ( )
	{
	}

}

$WP_Site_Links = new WP_Site_Links(  );

?>